pub fn is_agent() -> boolExpand description
Returns true when the current process is running inside an autonomous
coding agent or a AgentKind::Hybrid environment.
Equivalent to detect().map(|a| a.is_agent() || a.is_hybrid()).unwrap_or(false).
pub fn is_agent() -> boolReturns true when the current process is running inside an autonomous
coding agent or a AgentKind::Hybrid environment.
Equivalent to detect().map(|a| a.is_agent() || a.is_hybrid()).unwrap_or(false).