pub fn is_hybrid() -> boolExpand description
Returns true when the current process is running inside a
AgentKind::Hybrid environment (supports both agent and interactive use).
pub fn is_hybrid() -> boolReturns true when the current process is running inside a
AgentKind::Hybrid environment (supports both agent and interactive use).